# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: quotedatastructs.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
    name='quotedatastructs.proto',
    package='proto',
    serialized_pb='\n\x16quotedatastructs.proto\x12\x05proto\"/\n\rQueueDataBean\x12\x10\n\x08\x64\x61taType\x18\x01 \x02(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x02(\x0c\"&\n\x0fHistoryDataBean\x12\x13\n\x0bhistoryData\x18\x01 \x03(\x0c\"\xf5\x04\n\x08TickBean\x12\x14\n\x0cinstrumentID\x18\x01 \x02(\t\x12\x12\n\ntradingDay\x18\x02 \x02(\x05\x12\x11\n\tlastPrice\x18\x03 \x02(\x02\x12\x15\n\rpreClosePrice\x18\x04 \x02(\x02\x12\x11\n\topenPrice\x18\x05 \x02(\x02\x12\x14\n\x0chighestPrice\x18\x06 \x02(\x02\x12\x13\n\x0blowestPrice\x18\x07 \x02(\x02\x12\x0e\n\x06volume\x18\x08 \x01(\x03\x12\x10\n\x08turnover\x18\t \x01(\x03\x12\x14\n\x0copenInterest\x18\n \x01(\x03\x12\x17\n\x0fupperLimitPrice\x18\x0b \x02(\x02\x12\x17\n\x0flowerLimitPrice\x18\x0c \x02(\x02\x12\x12\n\nupdateTime\x18\r \x02(\x05\x12\x12\n\ncontractID\x18\x0e \x01(\t\x12\x1c\n\x14underlyingSecurityID\x18\x0f \x01(\t\x12\x11\n\tcallOrPut\x18\x10 \x01(\t\x12\x14\n\x0c\x65xerciseDate\x18\x11 \x01(\x05\x12\x10\n\x08preDelta\x18\x12 \x01(\x03\x12\x10\n\x08\x63urrDela\x18\x13 \x01(\x03\x12\x11\n\tnumTrades\x18\x14 \x01(\x03\x12\x16\n\x0etotalBidVolume\x18\x15 \x01(\x03\x12\x16\n\x0etotalAskVolume\x18\x16 \x01(\x03\x12\x1b\n\x13weightedAvgBidPrice\x18\x17 \x01(\x02\x12\x1b\n\x13weightedAvgAskPrice\x18\x18 \x01(\x02\x12\x10\n\x08\x61skPrice\x18\x19 \x03(\x02\x12\x11\n\taskVolume\x18\x1a \x03(\x05\x12\x10\n\x08\x62idPrice\x18\x1b \x03(\x02\x12\x11\n\tbidVolume\x18\x1c \x03(\x05\x12\x13\n\x0bsettlePrice\x18\x1d \x01(\x02\"\xf1\x01\n\tKLineBean\x12\x14\n\x0cinstrumentID\x18\x01 \x02(\t\x12\x12\n\ntradingDay\x18\x02 \x02(\x05\x12\x12\n\nupdateTime\x18\x03 \x02(\x05\x12\x11\n\topenPrice\x18\x04 \x02(\x02\x12\x11\n\thighPrice\x18\x05 \x02(\x02\x12\x10\n\x08lowPrice\x18\x06 \x02(\x02\x12\x12\n\nclosePrice\x18\x07 \x02(\x02\x12\x0e\n\x06volume\x18\x08 \x02(\x03\x12\x0f\n\x07turover\x18\t \x02(\x03\x12\x12\n\nmatchItems\x18\n \x02(\x03\x12\x10\n\x08interest\x18\x0b \x02(\x05\x12\x13\n\x0bsettlePrice\x18\x0c \x01(\x02\x42\'\n\x15\x63om.quant.quote.protoB\x0eQuoteDataProto')

_QUEUEDATABEAN = _descriptor.Descriptor(
    name='QueueDataBean',
    full_name='proto.QueueDataBean',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='dataType', full_name='proto.QueueDataBean.dataType', index=0,
            number=1, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=unicode("", "utf-8"),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='data', full_name='proto.QueueDataBean.data', index=1,
            number=2, type=12, cpp_type=9, label=2,
            has_default_value=False, default_value="",
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    options=None,
    is_extendable=False,
    extension_ranges=[],
    serialized_start=33,
    serialized_end=80,
)

_HISTORYDATABEAN = _descriptor.Descriptor(
    name='HistoryDataBean',
    full_name='proto.HistoryDataBean',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='historyData', full_name='proto.HistoryDataBean.historyData', index=0,
            number=1, type=12, cpp_type=9, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    options=None,
    is_extendable=False,
    extension_ranges=[],
    serialized_start=82,
    serialized_end=120,
)

_TICKBEAN = _descriptor.Descriptor(
    name='TickBean',
    full_name='proto.TickBean',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='instrumentID', full_name='proto.TickBean.instrumentID', index=0,
            number=1, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=unicode("", "utf-8"),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='tradingDay', full_name='proto.TickBean.tradingDay', index=1,
            number=2, type=5, cpp_type=1, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='lastPrice', full_name='proto.TickBean.lastPrice', index=2,
            number=3, type=2, cpp_type=6, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='preClosePrice', full_name='proto.TickBean.preClosePrice', index=3,
            number=4, type=2, cpp_type=6, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='openPrice', full_name='proto.TickBean.openPrice', index=4,
            number=5, type=2, cpp_type=6, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='highestPrice', full_name='proto.TickBean.highestPrice', index=5,
            number=6, type=2, cpp_type=6, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='lowestPrice', full_name='proto.TickBean.lowestPrice', index=6,
            number=7, type=2, cpp_type=6, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='volume', full_name='proto.TickBean.volume', index=7,
            number=8, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='turnover', full_name='proto.TickBean.turnover', index=8,
            number=9, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='openInterest', full_name='proto.TickBean.openInterest', index=9,
            number=10, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='upperLimitPrice', full_name='proto.TickBean.upperLimitPrice', index=10,
            number=11, type=2, cpp_type=6, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='lowerLimitPrice', full_name='proto.TickBean.lowerLimitPrice', index=11,
            number=12, type=2, cpp_type=6, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='updateTime', full_name='proto.TickBean.updateTime', index=12,
            number=13, type=5, cpp_type=1, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='contractID', full_name='proto.TickBean.contractID', index=13,
            number=14, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=unicode("", "utf-8"),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='underlyingSecurityID', full_name='proto.TickBean.underlyingSecurityID', index=14,
            number=15, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=unicode("", "utf-8"),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='callOrPut', full_name='proto.TickBean.callOrPut', index=15,
            number=16, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=unicode("", "utf-8"),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='exerciseDate', full_name='proto.TickBean.exerciseDate', index=16,
            number=17, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='preDelta', full_name='proto.TickBean.preDelta', index=17,
            number=18, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='currDela', full_name='proto.TickBean.currDela', index=18,
            number=19, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='numTrades', full_name='proto.TickBean.numTrades', index=19,
            number=20, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='totalBidVolume', full_name='proto.TickBean.totalBidVolume', index=20,
            number=21, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='totalAskVolume', full_name='proto.TickBean.totalAskVolume', index=21,
            number=22, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='weightedAvgBidPrice', full_name='proto.TickBean.weightedAvgBidPrice', index=22,
            number=23, type=2, cpp_type=6, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='weightedAvgAskPrice', full_name='proto.TickBean.weightedAvgAskPrice', index=23,
            number=24, type=2, cpp_type=6, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='askPrice', full_name='proto.TickBean.askPrice', index=24,
            number=25, type=2, cpp_type=6, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='askVolume', full_name='proto.TickBean.askVolume', index=25,
            number=26, type=5, cpp_type=1, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='bidPrice', full_name='proto.TickBean.bidPrice', index=26,
            number=27, type=2, cpp_type=6, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='bidVolume', full_name='proto.TickBean.bidVolume', index=27,
            number=28, type=5, cpp_type=1, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='settlePrice', full_name='proto.TickBean.settlePrice', index=28,
            number=29, type=2, cpp_type=6, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    options=None,
    is_extendable=False,
    extension_ranges=[],
    serialized_start=123,
    serialized_end=752,
)

_KLINEBEAN = _descriptor.Descriptor(
    name='KLineBean',
    full_name='proto.KLineBean',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='instrumentID', full_name='proto.KLineBean.instrumentID', index=0,
            number=1, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=unicode("", "utf-8"),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='tradingDay', full_name='proto.KLineBean.tradingDay', index=1,
            number=2, type=5, cpp_type=1, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='updateTime', full_name='proto.KLineBean.updateTime', index=2,
            number=3, type=5, cpp_type=1, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='openPrice', full_name='proto.KLineBean.openPrice', index=3,
            number=4, type=2, cpp_type=6, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='highPrice', full_name='proto.KLineBean.highPrice', index=4,
            number=5, type=2, cpp_type=6, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='lowPrice', full_name='proto.KLineBean.lowPrice', index=5,
            number=6, type=2, cpp_type=6, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='closePrice', full_name='proto.KLineBean.closePrice', index=6,
            number=7, type=2, cpp_type=6, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='volume', full_name='proto.KLineBean.volume', index=7,
            number=8, type=3, cpp_type=2, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='turover', full_name='proto.KLineBean.turover', index=8,
            number=9, type=3, cpp_type=2, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='matchItems', full_name='proto.KLineBean.matchItems', index=9,
            number=10, type=3, cpp_type=2, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='interest', full_name='proto.KLineBean.interest', index=10,
            number=11, type=5, cpp_type=1, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='settlePrice', full_name='proto.KLineBean.settlePrice', index=11,
            number=12, type=2, cpp_type=6, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    options=None,
    is_extendable=False,
    extension_ranges=[],
    serialized_start=755,
    serialized_end=996,
)

DESCRIPTOR.message_types_by_name['QueueDataBean'] = _QUEUEDATABEAN
DESCRIPTOR.message_types_by_name['HistoryDataBean'] = _HISTORYDATABEAN
DESCRIPTOR.message_types_by_name['TickBean'] = _TICKBEAN
DESCRIPTOR.message_types_by_name['KLineBean'] = _KLINEBEAN


class QueueDataBean(_message.Message):
    __metaclass__ = _reflection.GeneratedProtocolMessageType
    DESCRIPTOR = _QUEUEDATABEAN

    # @@protoc_insertion_point(class_scope:proto.QueueDataBean)


class HistoryDataBean(_message.Message):
    __metaclass__ = _reflection.GeneratedProtocolMessageType
    DESCRIPTOR = _HISTORYDATABEAN

    # @@protoc_insertion_point(class_scope:proto.HistoryDataBean)


class TickBean(_message.Message):
    __metaclass__ = _reflection.GeneratedProtocolMessageType
    DESCRIPTOR = _TICKBEAN

    # @@protoc_insertion_point(class_scope:proto.TickBean)


class KLineBean(_message.Message):
    __metaclass__ = _reflection.GeneratedProtocolMessageType
    DESCRIPTOR = _KLINEBEAN

    # @@protoc_insertion_point(class_scope:proto.KLineBean)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(),
                                                '\n\025com.quant.quote.protoB\016QuoteDataProto')
# @@protoc_insertion_point(module_scope)
